@@ -1,10 +1,10 @@
-import random
 import time
 import numpy as np
 from multiprocessing import Process,Queue
-from takagiabm.agent import GridAgent
+from takagiabm.agents.gridagents.freegrid.freegridagent import GridAgent
 from multiprocessing.managers import BaseManager
-import multiprocessing
+
+
 class MyManager(BaseManager):
     pass
 MyManager.register('GridAgent',GridAgent)
@@ -22,7 +22,8 @@ class Activator():
 ##        agentList=list(self.agentList)
         
         for agent in agentList:
-            agent.step()
+            if (agent.removed == False):
+                agent.step()
 
     def randomActivation(self,agentList:list,activatePortion=1)->None:#activatePortion是指激活的agent所占的比例.
         t0=time.time()
