@@ -28,6 +28,9 @@ class DiscreteGridCell(BaseAgent):
             raise Exception( \
                 '警告:agent或者cell的属性只能以字符串命名.你输入的是%s' % (repr(property)))
         self.properties[propertyName] = property
+    def setColorLater(self,color)->None:
+        self.grid.colorList[self.pos[1]][self.pos[0]]=getColorList(color)
+        self.setPropertyLater('color',color)
 
     def setColor(self,color:str)->None:
         self.properties['color']=color
