@@ -32,6 +32,9 @@ class Cell(BaseAgent):
         self.properties['color']=color
         self.grid.colorList[self.pos[1]][self.pos[0]]=getColorList(color)
 
+    def setColorLater(self,color)->None:
+        self.grid.colorList[self.pos[1]][self.pos[0]]=getColorList(color)
+        self.setPropertyLater('color',color)
 
     def onClicked(self):
         pass
\ No newline at end of file
