@@ -85,7 +85,7 @@ MyManager.register('Employee', Employee)
  
 def func1(em, lock):
     with lock:
-        em.increase()
+        em.step()
  
  
 if __name__ == '__main__':
